# by DCL manual
=begin
==NumRu::AdvancedDCL::Axis::Lin
==={W[ɂ
===Tv
Axis::LinW[͒Wn̍Wvbg邽߂̃W[ł.
, ϊ֐ԍ(Figtransnum)ƂĂ 1`4 (pWn)̐Kϊɑ΂Ă̂ݎgpł. ȊO̕ϊ֐ԍw肵Ă͕ۏ؂Ȃ. 

===p^
:uxuser (Float) <UZPACK>
   Y̍惋[`ɂďꏊp[^[Ƃ'U'serw肵ƂɗpXWl(l͕s). ڂDCL manual 3.2ߎQ.
:uyuser (Float) <UZPACK>
   X̍惋[`ɂďꏊp[^[Ƃ'U'serw肵ƂɗpYWl(l͕s). ڂ DCL manual 3.2ߎQ.	
:label(zs) (true or false) <UZPACK>
   x`ǂw肷p^; true Ȃ`, false Ȃ`Ȃ(l, true, false, true, true, false, true). DCL manual 3.6.3, 3.6.2, 3.6.1ߎQ.
:irotl(zs) (Fixnum) <UZPACK>
   x̉̕]pw肷p^; ]p90xPʂƂ鐮lŎw肷(l, 0, 0, 0, 0, 0, 0). DCL manual 3.4, 3.8.3ߎQ.
:irotc(zs) (Fixnum) <UZPACK>
   ^Cg̉̕]pw肷p^; ]p90xPʂƂ鐮lŎw肷(l, 0, 0, 0, +1, +1, +1). DCL manual 3.4, 3.8.5ߎQ.
:icent(zs) (Fixnum) <UZPACK>
   x̃̕Z^OIvVw肷p^; -1̂Ƃ悹, 0̂ƂZ^O,+1̂ƂE悹(l, 0, 0, 0, +1, +1, +1). DCL manual 3.4, 3.8.3ߎQ.
:indext(i) (Fixnum) <UZPACK>
   Wіڐ`̃CCfNXw肷p^(l, s, 1, 3). DCL manual 3.4, 3.8.2ߎQ.
:indexl(i) (Fixnum) <UZPACK>
   xу^Cg̕`̃CCfNXw肷p^(l, s, 3, 3). DCL manual 3.4, 3.8.3ߎQ.
:rsizet(i) (Float) <UZPACK>
   ڐ̒w肷p^(PʂVWn;l, s, 0.007, 0.014). DCL manual 3.4, 3.8.2ߎQ.
:rsizel(i) (Float) <UZPACK>
   x̍̕w肷p^(PʂVWn;l, s, 0.021, 0.028). DCL manual 3.4, 3.8.3ߎQ.
:rsizec(i) (Float) <UZPACK>
   ^Cg̍̕w肷p^(PʂVWn;l, s, 0.028, 0.035). 3.4, 3.8.5ߎQ.
:rsizec(i) (Float) <UZPACK>
   ^Cg̍̕w肷p^(PʂVWn;l, s, 0.028, 0.035). DCL manual 3.4, 3.8.5ߎQ.
:loffset (true or false) <UZPACK>
   WnjAItZbg邩ǂw肷p^. true Ȃ烊jAItZbg; false Ȃ炵Ȃ(l false). DCL manual 3.6ߎQ.
:xoffset (Float) <UZPACK>
   loffset  true ̂Ƃ,X̃ItZbglw肷p^(l0.0). DCL manual 3.6ߎQ.
:yoffset (Float) <UZPACK>
   loffset  true ̂Ƃ,ỸItZbglw肷p^(l0.0). DCL manual 3.6ߎQ.
:xfact (Float) <UZPACK>
   loffset  true ̂Ƃ,X̃t@N^[lw肷p^(l1.0). DCL manual 3.6ߎQ.
:yfact (Float) <UZPACK>
   loffset  true ̂Ƃ,Ỹt@N^[lw肷p^(l1.0). DCL manual 3.6ߎQ.
:pad1 (Float) <UZPACK>
   1Oɕ`W̍\vfǂꂾăx`w肷p^(l0.7; Pʂ͍`ƂĂ郉x̍1Ƃ).
:pad2 (Float) <UZPACK>
   W̃ItZbgʂIɌ߂鎞ɗpp^(l1.5; Pʂ̓p^ rsizec2 ̑傫1Ƃ).
:iflag (Fixnum) <UZPACK>
   W̐ݒ'U'serłȂꍇ,xƃ^Cĝǂ瑤ɕ`w肷p^. iflag ̂Ƃx Axis::Lin.xplbl ɂĂ͏㑤, Axis::Lin.yplbl ɂĂ͉Eɕ`.̂Ƃ͂̋tł. (l-1). DCL manual 3.8.3ߎQ.
:lbtwn (true or false) <UZPACK>
   x`ꏊɊւIvVw肷p^. lbtwn  true ȂԂɕ`; false Ȃ炻̏ꏊɕ`(l false). DCL manual 3.8.3ߎQ.
:rbtwn (Fixnum) <UZPACK>
   xԂɕ`Ƃ( lbtwn  true ̂Ƃ),ɂ̈ʒuڂw肷. -1.0̂Ƃ悹, 0.0̂ƂZ^O, +1.0̂ƂE悹(l0.0).
:lbound (true or false) <UZPACK>
   ^Cg`Ƃ, r[|[g̕zĂ܂悤ȂƂ,^Cg`ǂw肷. true Ȃ`Ȃ, false Ȃ`(l false).
:lbmsg (true or false) <UZPACK>
   lbound  true Ń^Cg`Xy[XȂƂ,G[bZ[Wo͂邩ǂw肷. true Ȃo͂, false Ȃo͂Ȃ(l true).
:inner (Fixnum) <UZPACK>
   ڐɌđł,OɌđłw肷p^. inner ̂ƂɌĖڐł; ̂ƂOɌĖڐł(l+1).
:iundef (Float) <UZPACK>
   lsł邱Ƃp^(l-999).
:cxfmt (String) <UXPACK::UXSFMT>
   X̃xtH[}bgݒ肷Bl͒16ȉ̕^ϐ. ƂΒlƂ '(F6.1)'̂悤Ɏw肷. l͌ŗL̃IvVł'B' (L3P^ŕ, _ȉɑ0͎菜; ɏ_ŉʂȂ炻菜). ܂AIɕl߂. ܂l1.2𕶎邽߂'(F4.1)'ƂĂ '(F8.1)'ƂĂԂl͂ǂ'1.2'ł. 
:cyfmt (String) <UYPACK::UYSFMT>
   ỸxtH[}bgݒ肷Bl͒16ȉ̕^ϐ. ƂΒlƂ '(F6.1)'̂悤Ɏw肷.
:roff(zs) (Float) <UZPACK>
   Ōɕ`x^Cg̎̋ێĂp^(l, 0, 0, 0, 0, 0, 0). DCL manual 3.8.1ߎQ.
:rofg(zs) (Float) <UZPACK>
   W{`ꏊǂꂾsړĕ`w肷p^(l, 0, 0, 0, 0, 0, 0). DCL manual 3.8.1ߎQ.

܂Ãp^̓\bhƂėp邱ƂłBȂ킿AAxis::Lin.labelxb Ńp^ labelxb ̎QƂAAxis::Lin.labelxb=Ńp^ labelxb ̕ύXłB

=end

module NumRu
  module AdvancedDCL
    module Axis
      module Lin
	def param_init
	  @param = Parameter.new(Axis.param)
	  @param.init("uxuser", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("uyuser", Float, "uzrset", "uzrget", 0, 0)
	  
	  @param.init("labelxb", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("labelxt", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("labelxu", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("labelyl", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("labelyr", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("labelyu", TrueClass, "uzlset", "uzlget", 0, 0)
	  
	  @param.init("irotlxb", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotlxt", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotlxu", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotlyl", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotlyr", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotlyu", Fixnum, "uziset", "uziget", 0, 0)
	  
	  @param.init("irotcxb", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotcxt", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotcxu", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotcyl", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotcyr", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("irotcyu", Fixnum, "uziset", "uziget", 0, 0)
	  
	  @param.init("icentxb", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("icentxt", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("icentxu", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("icentyl", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("icentyr", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("icentyu", Fixnum, "uziset", "uziget", 0, 0)
	  
	  @param.init("indext0", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("indext1", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("indext2", Fixnum, "uziset", "uziget", 0, 0)
	
	  @param.init("indexl0", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("indexl1", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("indexl2", Fixnum, "uziset", "uziget", 0, 0)
	  
	  @param.init("rsizet0", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rsizet1", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rsizet2", Float, "uzrset", "uzrget", 0, 0)
	  
	  @param.init("rsizel0", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rsizel1", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rsizel2", Float, "uzrset", "uzrget", 0, 0)
	  
	  @param.init("rsizec0", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rsizec1", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rsizec2", Float, "uzrset", "uzrget", 0, 0)
	  
	  @param.init("loffset", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("xoffset", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("yoffset", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("xfact", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("yfact", Float, "uzrset", "uzrget", 0, 0)
	  
	  @param.init("pad1", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("pad2", Float, "uzrset", "uzrget", 0, 0)
	  
	  @param.init("iflag", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("lbtwn", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("rbtwn", Fixnum, "uziset", "uziget", 0, 0)
	  @param.init("lbound", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("lbmsg", TrueClass, "uzlset", "uzlget", 0, 0)
	  @param.init("inner", Fixnum, "uziset", "uziget", 0, 0)
	  
	  @param.init("cxfmt", String, "uxsfmt", "uxqfmt", 1, 1)
	  @param.init("cyfmt", String, "uysfmt", "uyqfmt", 1, 1)
	  
	  @param.init("roffxu", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("roffyu", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rofgxb", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rofgxt", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rofgxu", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rofgyl", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rofgyr", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("rofgyu", Float, "uzrset", "uzrget", 0, 0)
	  
	  @param.init("roffxt", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("roffxb", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("roffyl", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("roffyr", Float, "uzrset", "uzrget", 0, 0)
	  @param.init("iundef", Fixnum, "uziset", "uziget", 0, 0)
	  
	  @temp_param = @param.dup
	  @backup = @param.dup
	end
	
	private :param_init

#------------------- method for parameters----------------------

	def set(key, val)
	  @param[key] = val
	end  

# by kawanabe
=begin
---Axis::Lin.set(key, val)
    p^̐ݒsB

    
    * key:p^(String)
    * val:ݒ肷lB^͊ep^QƂ̂ƁB
    gp
        Axis::Lin.set("labelxb", false)      # X-bottom Ƀx`Ȃ悤ɐݒ

=end
	def get(key)
	  @param[key]
	end

# by kawanabe
=begin
---Axis::Lin.get(key)
    p^QƂB

    
    * key:p^(String)
    gp
        Axis::Lin.get("labelxb")      #X-bottom Ƀx`ǂQƂB

=end

	def zfact(rfact)
	  @param["rsizet1"] = @param["rsizet1"] * rfact
	  @param["rsizet2"] = @param["rsizet2"] * rfact 
	  @param["rsizel1"] = @param["rsizel1"] * rfact
	  @param["rsizel2"] = @param["rsizel2"] * rfact
	  @param["rsizec1"] = @param["rsizec1"] * rfact
	  @param["rsizec2"] = @param["rsizec2"] * rfact
	end

# by DCL manual
=begin
---Axis::Lin.zfact(rfact)
    p^ 'rsize(i)', 'rsize(i)', 'rsizec(i)' (i=1,2) ׂĉ{.

    
    * rfact: {邩w肷l.(Float or Fixnum)

    l
    (1)̃\bhUZFACTĂłB

=end

#----------------------------------------------------------
#------------ draw method ----------------------

	def xaxdv(cside, dx1, dx2, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  DCL.uxaxdv(cside, dx1, dx2)
	  @backup.sync
	  @temp_param.clear
	end

# by DCL manual
=begin
---Axis::Lin.xaxdv(cside, dx1, dx2, x=nil, y=nil, temp=nil)
    ڐƃx`Ԋuw肵XW`. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * dx1 (Float) : ߂̖ڐ` Ԋuw肷(UWn̒lŎw肷).
    * dx2 (Float) : 傫߂̖ڐ x`Ԋuw肷(UWn̒lŎw肷). dx2 ͂ꂼ dx1  {łȂ΂ȂȂ.
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1) ̃\bh UXAXDV ĂłB
    (2) ڐуx͎w肵Ԋu̐{̏ꏊɕ`. 
    (3) Axis::Lin.xaxdv  Axis::Lin.xpaxs (islct=2) Ŏ`Ă; Axis::Lin.xptmk (islct=1)ŏ߂̖ڐ`Ă; Axis::Lin.xptmk (islct=2)ő傫߂̖ڐ`Ă; Axis::Lin.xpnum (islct=1)Ńx`Ă. 
    (4) ̃[`͖ڐƃx`ꏊŐ Axis::Lin.xptmk ȂǂĂł. Axis::Lin.xptmk Ă UXPTMK ̍Ɨpz̐񂩂ڐłő吔 200 ȉłȂ΂ȂȂ. 
    (5) x̃tH[}bg p^ cxfmt ɂĕύXł. 
    (6)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end

	def yaxdv(cside, dy1, dy2, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  DCL.uyaxdv(cside, dy1, dy2)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.yaxdv(cside, dy1, dy2, x=nil, y=nil, temp=nil)
    ڐƃx`Ԋuw肵XW`. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * dy1 (Float) : ߂̖ڐ` Ԋuw肷(UWn̒lŎw肷).
    * dy2 (Float) : 傫߂̖ڐ x`Ԋuw肷(UWn̒lŎw肷). dy2 ͂ꂼ dy1  {łȂ΂ȂȂ.
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1) ̃\bh UYAXDV ĂłB
    (2) ڐуx͎w肵Ԋu̐{̏ꏊɕ`. 
    (3) Axis::Lin.yaxdv  Axis::Lin.ypaxs (islct=2) Ŏ`Ă; Axis::Lin.yptmk (islct=1)ŏ߂̖ڐ`Ă; Axis::Lin.yptmk (islct=2)ő傫߂̖ڐ`Ă; Axis::Lin.ypnum (islct=1)Ńx`Ă. 
    (4) ̃[`͖ڐƃx`ꏊŐ Axis::Lin.yptmk ȂǂĂł. Axis::Lin.yptmk Ă UYPTMK ̍Ɨpz̐񂩂ڐłő吔 200 ȉłȂ΂ȂȂ. 
    (5) x̃tH[}bg p^ cyfmt ɂĕύXł. 
    (6)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end

	def xaxlb(cside, ux1, ux2, ch, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  nc = 1
	  ch.each{|i|
	    if(i.type != String)
	      raise ArgumentError, "elements of the 4th argument must be String"
	    end
	    
	    if(i.length > nc)
	      nc = i.length
	    end
	  }
	  
	  DCL.uxaxlb(cside, ux1, ux1.length, ux2, ch, nc, ux2.length)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.xaxlb(cside, ux1, ux2, ch, x=nil, y=nil, temp=nil)
    ڐƃx`ꏊw肵XW`. `xw肷. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * ux1 (Array or NArray) : ߂̖ڐ`ꏊi[z(UWn̒lŎw肷).
    * ux2 (Array or NArray) : 傫߂̖ڐуx`ꏊi[z (UWn̒lŎw肷).
    * ch (Array) : `xi[^z.
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1) ̃\bh UXAXLB ĂłB
    (2) Axis::Lin.xaxlb ͂ꂼ Axis::Lin.xpaxs (islct=2)Ŏ`Ă; Axis::Lin.xptmk (islct=1)ŏ߂̖ڐ`Ă; Axis::Lin.xptmk (islct=2)ő傫߂̖ڐ`Ă; Axis::Lin.xplbl (islct=1)Ńx`Ă. 
    (3)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B      
=end
        
	def yaxlb(cside, uy1, uy2, ch, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  #Fig.settrf
	
	  nc = 1
	  ch.each{|i|
	    if(i.type != String)
	      raise ArgumentError, "elements of the 4th argument must be String"
	    end
	    
	    if(i.length > nc)
	      nc = i.length
	    end
	  }
	  
	  DCL.uyaxlb(cside, uy1, uy1.length, uy2, ch, nc, uy2.length)
	  @backup.sync
	  @temp_param.clear
	end

 
# by DCL manual
=begin
---Axis::Lin.yaxlb(cside, uy1, uy2, ch, x=nil, y=nil, temp=nil)
    ڐƃx`ꏊw肵YW`. `xw肷. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * ux1 (Array or NArray) : ߂̖ڐ`ꏊi[z(UWn̒lŎw肷).
    * ux2 (Array or NArray) : 傫߂̖ڐуx`ꏊi[z (UWn̒lŎw肷).
    * ch (Array) : `xi[^z.
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1) ̃\bh UYAXLB ĂłB
    (2) Axis::Lin.yaxlb ͂ꂼ Axis::Lin.ypaxs (islct=2)Ŏ`Ă; Axis::Lin.yptmk (islct=1)ŏ߂̖ڐ`Ă; Axis::Lin.yptmk (islct=2)ő傫߂̖ڐ`Ă; Axis::Lin.yplbl (islct=1)Ńx`Ă. 
    (3)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B
=end
      
	def xpaxs(cside, islct, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  DCL.uxpaxs(cside, islct)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.xpaxs(cside, islct, x=nil, y=nil, temp=nil)
    `.

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1) ̃\bhUXPAXSĂłB
    (2) ̃CCfNX̓p^ index0, index1, index2߂. 
    (3) \vf`ꏊɈˑp^Ƃ roff(zs) (zs='xb','xt','xu','yl','yr','yu'). , Ōɕ`x^Cg̎̋ێĂp^ł. ̃p^Ȃ, x^Cg͎X EChE̊OɌďdȂȂ悤`. 
    (4) W, {`ׂꏊ畽sړꏊɕ`Ƃł (DCL manual 3.2ߎQ). ̈ړʂ, `ꏊɈˑp^ rofg(zs) Ǘ (lׂ͂0). ̒lX/Yꂼɂ, \bh 
          Axis::Lin.xsaxz(cside, roffx) / Axis::Lin.ysaxz(cside, roffy) 
        ɂĐݒł. ܂ItZbgʂIɌ肷郋[` 
          Axis::Lin.uxsaxs(cside) / Axis::Lin.ysaxs(cside) 
        ɂĂݒł. ItZbgʂ̓p^ pad2 ɂƂÂČvZ. 
    (5) p^roff(zs)  rofg(zs) ƂɌĎ`. ̓ϐ DCL(rbdcl) ̃Tu[` UZINIT ɂ 0 ɃZbg. ʃ[U[ UZINIT zɌĂԕKv͂Ȃ.
    (6)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
 
	def ypaxs(cside, islct, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  DCL.uypaxs(cisde, islct)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.ypaxs(cside, islct, x=nil, y=nil, temp=nil)
    `.

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1) ̃\bhUYPAXSĂłB
    (2) ̃CCfNX̓p^ index0, index1, index2߂. 
    (3) \vf`ꏊɈˑp^Ƃ roff(zs) (zs='xb','xt','xu','yl','yr','yu'). , Ōɕ`x^Cg̎̋ێĂp^ł. ̃p^Ȃ, x^Cg͎X EChE̊OɌďdȂȂ悤`. 
    (4) W, {`ׂꏊ畽sړꏊɕ`Ƃł (DCL manual 3.2ߎQ). ̈ړʂ, `ꏊɈˑp^ rofg(zs) Ǘ (lׂ͂0). ̒lX/Yꂼɂ, \bh 
          Axis::Lin.xsaxz(cside, roffx) / Axis::Lin.ysaxz(cside, roffy) 
        ɂĐݒł. ܂ItZbgʂIɌ肷郋[` 
          Axis::Lin.uxsaxs(cside) / Axis::Lin.ysaxs(cside) 
        ɂĂݒł. ItZbgʂ̓p^ pad2 ɂƂÂČvZ. 
    (5) p^roff(zs)  rofg(zs) ƂɌĎ`. ̓ϐ DCL(rbdcl) ̃Tu[` UZINIT ɂ 0 ɃZbg. ʃ[U[ UZINIT zɌĂԕKv͂Ȃ.
    (6)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
      
	def xplbl(cside, islct, ux, ch, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  nc = 1
	  ch.each{|i|
	    if(i.type != String)
	      raise ArgumentError, "elements of the 4th argument must be String"
	    end
	    
	    if(i.length > nc)
	      nc = i.length
	    end
	  }
	  
	  DCL.uxplbl(cside, islct, ux, ch, nc, ux.length)
	  @backup.sync
	  @temp_param.clear
	end

# by DCL manual
=begin
---Axis::Lin.xplbl(cside, islct, ux, ch, x=nil, y=nil, temp=nil)
    Ŏw肵x`.

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * ux (Array or NArray) : x`ꏊi[z.(UWn̒lŎw肷.)
    * ch (Array) : `xi[^z.
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1)̃\bhUXPLBLĂłB
    (2)̃pbP[Wł͎2ʂ̃x̕`. Axis::Lin.xplbl/yplblꂼɂ 
       * ux(i)/uy(i) ꏊch(i) x`. 
       * ux(i)/uy(i) ux(i+1)/uy(i+1) Ԃch(i)̃x`. 
       2̕@̂ǂIԂ̓p^ lbtwn ߂. lbtwn  true ȂԂɕ`; false Ȃ炻̏ꏊɕ`(l false). , xԂɕ`悤Ɏw肵ĂĂ, x2_̊Ԋu 傫Ƃx͕`Ȃ. ܂bZ[Wo͂Ȃ. 
    (3)x̍̓̕p^ rsizel(i) ߂. 
    (4)x̉̕]p̓p^ irotl(zs) ߂. 
    (5)x̃̕Z^OIvV̓p^ icent(zs) ߂. 
    (6)x̕`̃CCfNX̓p^ indexl(i) ߂. 
    (7)cside Ƃ'U'ȊOw肵ꍇ, x͏ɃEChE̊Oɕ`. cside Ƃ'U'w肵ꍇ, x̕`ʒu̓p^ iflag ߂. iflag ̂ƂxAxis::Lin.xplbl ɂĂ͏㑤, Axis::Lin.yplbl ɂĂ͉Eɕ`. ̂Ƃ͂̋tł. l-1. 
    (8) 1Oɕ`W̍\vfǂꂾăx` ϐ pad1 ߂. l0.7. Pʂ͍`ƂĂ郉x̍1Ƃ.
    (9)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
 
	def yplbl(cside, islct, uy, ch, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	
	Fig.settrf
	  
	  nc = 1
	  ch.each{|i|
	    if(i.type != String)
	      raise ArgumentError, "elements of the 4th argument must be String"
	    end
	    
	    if(i.length > nc)
	      nc = i.length
	    end
	  }
	  
	  DCL.uyplbl(cside, islct, uy, ch, nc, uy.length)
	  @backup.sync
	  @temp_param.clear
	end

      
# by DCL manual
=begin
---Axis::Lin.yplbl(cside, islct, uy, ch, x=nil, y=nil, temp=nil)
    Ŏw肵x`.

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * uy (Array or NArray) : x`ꏊi[z.(UWn̒lŎw肷.)
    * ch (Array) : `xi[^z.
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1)̃\bhUYPLBLĂłB
    (2)̃pbP[Wł͎2ʂ̃x̕`. Axis::Lin.xplbl/yplblꂼɂ 
       * ux(i)/uy(i) ꏊch(i) x`. 
       * ux(i)/uy(i) ux(i+1)/uy(i+1) Ԃch(i)̃x`. 
       2̕@̂ǂIԂ̓p^ lbtwn ߂. lbtwn  true ȂԂɕ`; false Ȃ炻̏ꏊɕ`(l false). , xԂɕ`悤Ɏw肵ĂĂ, x2_̊Ԋu 傫Ƃx͕`Ȃ. ܂bZ[Wo͂Ȃ. 
    (3)x̍̓̕p^ rsizel(i) ߂. 
    (4)x̉̕]p̓p^ irotl(zs) ߂. 
    (5)x̃̕Z^OIvV̓p^ icent(zs) ߂. 
    (6)x̕`̃CCfNX̓p^ indexl(i) ߂. 
    (7)cside Ƃ'U'ȊOw肵ꍇ, x͏ɃEChE̊Oɕ`. cside Ƃ'U'w肵ꍇ, x̕`ʒu̓p^ iflag ߂. iflag ̂ƂxAxis::Lin.xplbl ɂĂ͏㑤, Axis::Lin.yplbl ɂĂ͉Eɕ`. ̂Ƃ͂̋tł. l-1. 
    (8) 1Oɕ`W̍\vfǂꂾăx` ϐ pad1 ߂. l0.7. Pʂ͍`ƂĂ郉x̍1Ƃ.
    (9)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end

	def xpnum(cside, islct, ux, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  DCL.uxpnum(cside, islct, ux, ux.length)
	  @backup.sync
	  @temp_param.clear
	end

# by DCL manual
=begin
---Axis::Lin.xpnum(cside, islct, ux, x=nil, y=nil, temp=nil)
    lŎw肵x`.

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * ux (Array or NArray) : x`ꏊi[z.(UWn̒lŎw肷.)
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1) ̃\bh UXPNUM ĂłB
    (2) ̃\bh, DCL(rbdcl) ̃Tu[`CHVAL (uMISC1v}jAFMTLIBQ) gux, uy̒l𕶎Ƃ Axis::Lin.xplbl/yplbl Ăł. (x̑ɂĂ, Axis::Lin.plbl/yplbl QƂ̂. ) Axis::Lin.xplbl/yplbl ɓn^zŗpӂĂ邽 ux, uy̒40ȉłȂ΂ȂȂ. 
    (3) Tu[` CHVAL ɓntH[}bg, Axis::Lin.xpnum ɂĂ̓p^ cxfmt Őݒ/QƂ邱Ƃł. Axis::Lin.ypnum ɂĂ̓p^ cyfmt Őݒ/QƂ邱Ƃł. cxfmt, cyfmt ͒16ȉ̕^ϐ. Ƃ '(F6.1)' ̂悤Ɏw肷. l CHVAL ɌŗL̃IvVł 'B' (L3P^ŕ, _ȉɑ0͎菜; ɏ_ŉʂȂ炻菜). CHVAL ͎Iɕl߂. ܂l 1.2 𕶎邽߂ '(F4.1)' ƂĂ  '(F8.1)' ƂĂ CHVAL Ԃl͂ǂ '1.2' ł. 
    (4)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end

	def ypnum(cside, islct, uy, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  DCL.uypnum(cside, islct, uy, uy.length)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.ypnum(cside, islct, uy, x=nil, y=nil, temp=nil)
    lŎw肵x`.

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * uy (Array or NArray) : x`ꏊi[z.(UWn̒lŎw肷.)
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1) ̃\bh UYPNUM ĂłB
    (2) ̃\bh, DCL(rbdcl) ̃Tu[`CHVAL (uMISC1v}jAFMTLIBQ) gux, uy̒l𕶎Ƃ Axis::Lin.xplbl/yplbl Ăł. (x̑ɂĂ, Axis::Lin.plbl/yplbl QƂ̂. ) Axis::Lin.xplbl/yplbl ɓn^zŗpӂĂ邽 ux, uy̒40ȉłȂ΂ȂȂ. 
    (3) Tu[` CHVAL ɓntH[}bg, Axis::Lin.xpnum ɂĂ̓p^ cxfmt Őݒ/QƂ邱Ƃł. Axis::Lin.ypnum ɂĂ̓p^ cyfmt Őݒ/QƂ邱Ƃł. cxfmt, cyfmt ͒16ȉ̕^ϐ. Ƃ '(F6.1)' ̂悤Ɏw肷. l CHVAL ɌŗL̃IvVł 'B' (L3P^ŕ, _ȉɑ0͎菜; ɏ_ŉʂȂ炻菜). CHVAL ͎Iɕl߂. ܂l 1.2 𕶎邽߂ '(F4.1)' ƂĂ  '(F8.1)' ƂĂ CHVAL Ԃl͂ǂ '1.2' ł. 
    (4)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
      
	def xptmk(cside, islct, ux, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
	  
	  DCL.uxptmk(cside, islct, ux, ux.length)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.xptmk(cside, islct, ux, x=nil, y=nil, temp=nil)
    ڐ`. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * ux (Array or NArray) : x`ꏊi[z.(UWn̒lŎw肷.)
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXPTMK ĂłB
    (2)ڐ̒̓p^ rsizet(i) ߂. 
    (3)ڐ`̃CCfNX̓p^ indext(1) ߂. 
    (4)ڐɌđł, OɌđł p^ inner ߂. inner ̂ƂɌĖڐł; ̂ƂOɌĖڐł (l+1).  
    (5)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end

	def yptmk(cside, islct, uy, x=nil, y=nil, temp=nil)
	  if(x.is_a?(Hash))
	    temp = x
	  elsif((x.is_a?(NArray))&&(x.rank==2))
	    y = x.shape[1].to_f
	    x = x.shape[0].to_f
	    Basics.checkundef(x, y)
	  elsif(Basics.typearray(x) && Basics.typearray(y))
	    Basics.checkundef(x, y)
	  elsif(x==nil&&y==nil)
	    Basics.checkundef(1.0, 1.0)
	  end
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  Fig.settrf
		
	  DCL.uyptmk(cside, islct, uy, uy.length)
	  @backup.sync
	  @temp_param.clear
	end

# by DCL manual
=begin
---Axis::Lin.yptmk(cside, islct, ux, x=nil, y=nil, temp=nil)
    ڐ`. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * ux (Array or NArray) : x`ꏊi[z.(UWn̒lŎw肷.)
    * x, y (Array or NArray) : XAY̍W\z
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYPTMK ĂłB
    (2)ڐ̒̓p^ rsizet(i) ߂. 
    (3)ڐ`̃CCfNX̓p^ indext(1) ߂. 
    (4)ڐɌđł, OɌđł p^ inner ߂. inner ̂ƂɌĖڐł; ̂ƂOɌĖڐł (l+1).  
    (5)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
      
	def xpttl(cside, islct, cttl, px, temp=nil)
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  #Fig.settrf
	  
	  DCL.uxpttl(cside, islct, cttl, px)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.xpttl(cside, islct, cttl, px, temp=nil)
    ^Cg`. 

     
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXPTTL ĂłB
    (2)^Cg̑̕傫̓p^ rsizec(i) ߂. 
    (3)^Cg̉̕]p̓p^ irotc(zs) ߂. 
    (4)^Cg̕`̃CCfNX̓p^ indexl(i)߂. 
    (5)p^ lbound  true  ^CgEChE̕ƃ^Cg`Ȃ; false ȂEChE̕Ă` (l false). ܂, p^ lbound  true  ^CgEChE̕ĕ`ȂƂ p^ lbmsg  true Ȃ ̎|bZ[Wo͂; false Ȃo͂Ȃ (l true). 

=end

	def ypttl(cside, islct, cttl, py, temp=nil)
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  #Fig.settrf
	  
	  DCL.uypttl(cside, islct, cttl, py)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.ypttl(cside, islct, cttl, py, temp=nil)
    ^Cg`. 

     
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * py (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYPTTL ĂłB
    (2)^Cg̑̕傫̓p^ rsizec(i) ߂. 
    (3)^Cg̉̕]p̓p^ irotc(zs) ߂. 
    (4)^Cg̕`̃CCfNX̓p^ indexl(i)߂. 
    (5)p^ lbound  true  ^CgEChE̕ƃ^Cg`Ȃ; false ȂEChE̕Ă` (l false). ܂, p^ lbound  true  ^CgEChE̕ĕ`ȂƂ p^ lbmsg  true Ȃ ̎|bZ[Wo͂; false Ȃo͂Ȃ (l true). 

=end

	def xmttl(cside, cttl, px, temp=nil)
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  #Fig.settrf
	  
	  DCL.uxmttl(cside, cttl, px)
	  @backup.sync
	  @temp_param.clear
	end

# by DCL manual
=begin
---Axis::Lin.xmttl(cside, cttl, px, temp=nil)
    傫߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXMTTL ĂłB
    (2)̃\bh UXPTTL (ISLCT=2)g ^Cg`Ă.

=end
 
	def ymttl(cside, cttl, py, temp=nil)
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  #Fig.settrf
	  
	  DCL.uymttl(cside, cttl, py)
	  @backup.sync
	  @temp_param.clear
	end

# by DCL manual
=begin
---Axis::Lin.ymttl(cside, cttl, py, temp=nil)
    傫߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYMTTL ĂłB
    (2)̃\bh UYPTTL (ISLCT=2)g ^Cg`Ă.

=end
	
	def xsttl(cside, cttl, px, temp=nil)
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  #Fig.settrf
	  
	  DCL.uxsttl(cside, cttl, px)
	  @backup.sync
	  @temp_param.clear
	end
	
# by DCL manual
=begin
---Axis::Lin.xsttl(cside, cttl, px, temp=nil)
    ߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXSTTL ĂłB
    (2)̃\bh UXPTTL (ISLCT=1)g ^Cg`Ă.

=end
    
	def ysttl(cside, cttl, py, temp=nil)
	  @param.sync
	  @backup = @temp_param.set(temp, @param, @backup)
	  @temp_param.sync
	  
	  #Fig.settrf
	  
	  DCL.uysttl(cside, cttl, py)
	  @backup.sync
	  @temp_param.clear
	end

# by DCL manual
=begin
---Axis::Lin.ysttl(cside, cttl, py, temp=nil)
    ߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYSTTL ĂłB
    (2)̃\bh UYPTTL (ISLCT=1)g ^Cg`Ă.

=end
	
	def xsaxz(cside, roffx)
	  DCL.uxsaxz(cside, roffx)
	end
	
	def ysaxz(cside, roffy)
	  DCL.uysaxz(cside, roffy)
	end
	
	def xsaxs(cside)
	  DCL.uxsaxs(cside)
	end
	
	def ysaxs(cside)
	  DCL.uysaxs(cside)
	end
	
	module_function :param_init
	module_function :set
	module_function :get
	module_function :zfact
	module_function :xaxdv
	module_function :yaxdv
	module_function :xaxlb
	module_function :yaxlb
	module_function :xpaxs
	module_function :ypaxs
	module_function :xplbl
	module_function :yplbl
	module_function :xpnum
	module_function :ypnum
	module_function :xptmk
	module_function :yptmk
	module_function :xpttl
	module_function :ypttl
	module_function :xmttl
	module_function :ymttl
	module_function :xsttl
	module_function :ysttl
	module_function :xsaxz
	module_function :ysaxz
	module_function :xsaxs
	module_function :ysaxs
	
	param_init
	
	@param.keys.each{|i|
	  eval "def #{i}; @param['#{i}']; end"
	  eval "def #{i}=(val); set('#{i}', val); end"
	}
      
	@param.keys.each{|i|
	  eval "module_function :#{i}"
	  eval "module_function :#{i}="
	}
      end
    end
  end
end
